@@ -63,7 +63,7 @@ ExperimentRow = collections.namedtuple(
     'ExperimentRow', ['exp_id', 'expid', 'status', 'seconds'])
 
 JobRow = collections.namedtuple(
-    'JobRow', ['name', 'queue_time', 'run_time', 'status', 'energy', 'submit', 'start', 'finish', 'ncpus'])
+    'JobRow', ['name', 'queue_time', 'run_time', 'status', 'energy', 'submit', 'start', 'finish', 'ncpus', 'run_id'])
 
 
 class ExperimentRun():
@@ -950,7 +950,7 @@ class JobDataStructure(MainDataBase):
                     print(exp)
                     pass
 
-    def __repr__(self):
+    def __str__(self):
         return '{} {}'.format("Data structure. Version:", self.db_version)
 
     def process_current_run_collection(self, allJobs, job_worker_database=None):
@@ -1719,33 +1719,6 @@ class JobDataStructure(MainDataBase):
                 run_id, "_get_experiment_run_by_id"))
             return None
 
-    # def _get_experiment_run_ids_from_period(self, period_start):
-    #     """
-    #     This function receives period start in timestamp format (int)
-    #     Then it returns the unique run_id of the jobs that fall in this period.
-    #     :param period_start: timestamp
-    #     :type period_start: int
-    #     :return:
-    #     :rtype: list of int
-    #     """
-    #     try:
-    #         if self.conn:
-    #             self.conn.text_factory = str
-    #             cur = self.conn.cursor()
-    #             cur.execute(
-    #                 "select run_id from job_data where start >= ? or finish >= ? GROUP BY run_id", (period_start, period_start))
-    #             rows = cur.fetchall()
-    #             print(type(rows))
-    #             if len(rows) > 0:
-    #                 return rows
-    #             else:
-    #                 return None
-    #     except Exception as exp:
-    #         print(exp)
-    #         return None
-
-    #     return None
-
     def _select_pragma_version(self):
         """ Retrieves user_version from database
         """
