@@ -124,28 +124,28 @@ class Monitor:
         Log.debug('Creating workflow graph...')
         graph = pydotplus.Dot(graph_type='digraph')
 
-        Log.debug('Creating legend...')
-        legend = pydotplus.Subgraph(
-            graph_name='Legend', label='Legend', rank="source")
-        legend.add_node(pydotplus.Node(name='UNKNOWN', shape='box', style="",
-                                       fillcolor=self._table[Status.UNKNOWN]))
-        legend.add_node(pydotplus.Node(name='WAITING', shape='box', style="filled",
-                                       fillcolor=self._table[Status.WAITING]))
-        legend.add_node(pydotplus.Node(name='READY', shape='box', style="filled",
-                                       fillcolor=self._table[Status.READY]))
-        legend.add_node(pydotplus.Node(name='SUBMITTED', shape='box', style="filled",
-                                       fillcolor=self._table[Status.SUBMITTED]))
-        legend.add_node(pydotplus.Node(name='QUEUING', shape='box', style="filled",
-                                       fillcolor=self._table[Status.QUEUING]))
-        legend.add_node(pydotplus.Node(name='RUNNING', shape='box', style="filled",
-                                       fillcolor=self._table[Status.RUNNING]))
-        legend.add_node(pydotplus.Node(name='COMPLETED', shape='box', style="filled",
-                                       fillcolor=self._table[Status.COMPLETED]))
-        legend.add_node(pydotplus.Node(name='FAILED', shape='box', style="filled",
-                                       fillcolor=self._table[Status.FAILED]))
-        legend.add_node(pydotplus.Node(name='SUSPENDED', shape='box', style="filled",
-                                       fillcolor=self._table[Status.SUSPENDED]))
-        graph.add_subgraph(legend)
+        # Log.debug('Creating legend...')
+        # legend = pydotplus.Subgraph(
+        #     graph_name='Legend', label='Legend', rank="source")
+        # legend.add_node(pydotplus.Node(name='UNKNOWN', shape='box', style="",
+        #                                fillcolor=self._table[Status.UNKNOWN]))
+        # legend.add_node(pydotplus.Node(name='WAITING', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.WAITING]))
+        # legend.add_node(pydotplus.Node(name='READY', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.READY]))
+        # legend.add_node(pydotplus.Node(name='SUBMITTED', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.SUBMITTED]))
+        # legend.add_node(pydotplus.Node(name='QUEUING', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.QUEUING]))
+        # legend.add_node(pydotplus.Node(name='RUNNING', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.RUNNING]))
+        # legend.add_node(pydotplus.Node(name='COMPLETED', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.COMPLETED]))
+        # legend.add_node(pydotplus.Node(name='FAILED', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.FAILED]))
+        # legend.add_node(pydotplus.Node(name='SUSPENDED', shape='box', style="filled",
+        #                                fillcolor=self._table[Status.SUSPENDED]))
+        # graph.add_subgraph(legend)
 
         exp = pydotplus.Subgraph(
             graph_name='Experiment', label=expid, name="maingroup")
@@ -232,21 +232,21 @@ class Monitor:
             graph.set_strict(True)
 
         graph.add_subgraph(exp)
-        nodes_in_wrapper = list()
-        not_to_fake = list()
-        for node in exp.get_nodes():
-            name = node.obj_dict['name']
-            if name in jobs_packages_dict:
-                package = jobs_packages_dict[name]
-                # print(package)
-                if package not in packages_subgraphs_dict:
-                    packages_subgraphs_dict[package] = pydotplus.Cluster(
-                        graph_name=package)
-                    packages_subgraphs_dict[package].obj_dict['attributes']['color'] = 'black'
-                    packages_subgraphs_dict[package].obj_dict['attributes']['style'] = 'dashed'
-                packages_subgraphs_dict[package].add_node(node)
-                nodes_in_wrapper.append(name)
-        print(len(date_member_cluster.keys()))
+        # nodes_in_wrapper = list()
+        # not_to_fake = list()
+        # for node in exp.get_nodes():
+        #     name = node.obj_dict['name']
+        #     if name in jobs_packages_dict:
+        #         package = jobs_packages_dict[name]
+        #         # print(package)
+        #         if package not in packages_subgraphs_dict:
+        #             packages_subgraphs_dict[package] = pydotplus.Cluster(
+        #                 graph_name=package)
+        #             packages_subgraphs_dict[package].obj_dict['attributes']['color'] = 'black'
+        #             packages_subgraphs_dict[package].obj_dict['attributes']['style'] = 'dashed'
+        #         packages_subgraphs_dict[package].add_node(node)
+        #         # nodes_in_wrapper.append(name)
+        # print(len(date_member_cluster.keys()))
         # for node in exp.get_nodes():
         #     name = node.obj_dict['name']
         #     if name in date_member_cluster.keys():
@@ -260,11 +260,11 @@ class Monitor:
         #             not_to_fake.append(name_fake_group)
         # print("Done")
 
-        for package, cluster in packages_subgraphs_dict.items():
-            if package not in not_to_fake:
-                # print(package)
-                # print(cluster)
-                graph.add_subgraph(cluster)
+        # for package, cluster in packages_subgraphs_dict.items():
+        #     if package not in not_to_fake:
+        #         # print(package)
+        #         # print(cluster)
+        #         graph.add_subgraph(cluster)
 
         # for name in date_member_cluster.keys():
         #     for h in date_member_cluster[name]:
