@@ -23,9 +23,9 @@ from experiment.common_requests import get_experiment_pkl, get_experiment_stats,
 from experiment.common_requests import get_experiment_data, get_experiment_graph, get_experiment_run, get_experiment_summary, get_current_status_log_plus
 from experiment.common_requests import get_experiment_metrics, get_quick_view, get_job_history, get_experiment_runs, get_experiment_run_detail, get_experiment_tree_rundetail
 from experiment.common_requests import get_last_test_archive_status, get_job_log, get_experiment_counters, get_current_configuration_by_expid
-
 # Bad practices block ends
 import experiment.utils as Utiles
+from performance.performance_metrics import PerformanceMetrics
 from database.db_common import search_experiment_by_id
 import os
 import jwt
@@ -310,7 +310,7 @@ def get_expsummary(expid):
 def get_exp_performance(expid):
     start_time = time.time()
     app.logger.info('PRF|RECEIVED|' + str(expid))
-    result = get_experiment_metrics(expid)
+    result = PerformanceMetrics(expid).to_json() #get_experiment_metrics(expid)
     app.logger.info('PRF|RTIME|' + str(expid) + "|" +
                     str(time.time() - start_time))
     return result
